.. py:function:: sf_elljac_e(u, m [, ret, dn, cn, sn])

    Wrapper for :c:func:`gsl_sf_elljac_e`
    c code signature: int gsl_sf_elljac_e( double u,  double m, double* sn, double* cn, double* dn)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Od_d_d`
    
    :param double u: positional argument 0
    :param double m: positional argument 1
    :param int ret: positional argument 2
    :param double dn: positional argument 3
    :param double cn: positional argument 4
    :param double sn: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 2, :param double dn: positional argument 3, :param double cn: positional argument 4, :param double sn: positional argument 5) 
    :return: result 

